/////////
//       
// 
//   Main program for data analysis
//                                 
//   edit this macro for your own purposes
//
//
//                                        
/////////


#include <TROOT.h>
#include <TSystem.h>
#include <TString.h>

void Processor() {

  gROOT->ProcessLine(".L HbtFitter.C+");
  gROOT->ProcessLine(".L FemtoUtils.h+");
  gROOT->ProcessLine(".L DataProcessing.cxx+");

  DataProcessing xxx;
  Int_t partType = 4;                      // 3-pion, 4-kaon
  TString sInName, sParticle, sOutName;
  

  if(partType == 3) {
    sParticle = "Pion";
  }
  else if(partType == 4) {
    sParticle = "Kaon";
  }

  sInName = "/home/nigmatkulov/work/star/data/auau200/exp";
  sInName += sParticle;
  sInName += "HBT_auau200_2011.root";
  sOutName = "/home/nigmatkulov/work/star/soft/star_software/processing/auau/o";
  sOutName += sParticle;
  sOutName += "HBT_auau200_pid2.root";
  
  xxx.SetExpFile(sInName.Data());
  xxx.SetOutFile(sOutName.Data());
  xxx.SetDetectorSelection(2);
  xxx.SetSourceFunction(0);
  xxx.SetNonFemtoFunction(0);
  xxx.SetDrawLegend(true);
  xxx.SetParticleType(partType);

  xxx.DoProcessing();
}
